===============
Preprocess Text
===============

.. figure:: icons/preprocess.png

Preprocesses corpus with selected methods.

Signals
-------

**Inputs**:

-  **Corpus**

Corpus instance.

**Outputs**:

-  **Corpus**

Preprocessed corpus.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
